from django.contrib import admin

import models

class APIKeyAdmin(admin.ModelAdmin):
	list_display = ('key', 'user', 'created_at')
	fields = ('user',)
	ordering = ('-created_at',)

admin.site.register(models.APIKey, APIKeyAdmin)



from rest_framework.authentication import TokenAuthentication

import models

class APIKeyAuthentication(TokenAuthentication):
	keyword = 'API-Key'

	def get_model(self):
		if self.model is not None:
			return self.model
		return models.APIKey



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='APIKey',
            fields=[
                ('key', models.CharField(max_length=40, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from rest_framework import serializers

import models

class APIKeySerializer(serializers.ModelSerializer):
	class Meta:
		model = models.APIKey
		fields = ('key', 'created_at')
		read_only_fields = ('key', 'created_at')



from rest_framework import permissions, viewsets

import models
import serializers
import validators

class APIKeyViewSet(viewsets.ModelViewSet):
	serializer_class = serializers.APIKeySerializer
	lookup_field = 'key'
	lookup_value_regex = validators.hexadecimal_regex
	permission_classes = (permissions.IsAuthenticated,)
	filter_backends = ()

	# Only return API keys owned by the user
	def get_queryset(self):
		return models.APIKey.objects.filter(user=self.request.user)

	# Add the user on creation
	def perform_create(self, serializer):
		serializer.save(user=self.request.user)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(
	name = 'django_rest_apikey',
	description = 'Per-user API key to authenticate in Django REST Framework',
	version = '0.3.0',
	license = 'LGPL',
	author = 'Yamine BULACH',
	author_email = 'contact@yamine-bulach.eu',
	url = 'https://github.com/ybulach/django-rest-apikey',
	packages = [
		'django_rest_apikey',
		'django_rest_apikey.migrations'
	],
	install_requires = ['djangorestframework'],
	classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Framework :: Django',
    ],
)



import binascii
from django.contrib.auth.models import User
from django.db import models
import os

class APIKey(models.Model):
	key = models.CharField(max_length=40, primary_key=True)
	user = models.ForeignKey(User)
	created_at = models.DateTimeField(auto_now_add=True)

	def save(self, *args, **kwargs):
		if not self.key:
			self.key = binascii.hexlify(os.urandom(20)).decode()
		return super(APIKey, self).save(*args, **kwargs)

	def __unicode__(self):
		return self.key



from django.core import validators

_error_message = 'Characters must match regex %s'

# Hexadecimal values (i.e. 123456789abcdef)
hexadecimal_regex = r'[a-fA-F0-9]+'
validate_hexadecimal = validators.RegexValidator('^%s$' % hexadecimal_regex, _error_message % hexadecimal_regex, 'invalid')
